﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using FormWeb.Models.DB;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using Syncfusion.EJ2.Base;

namespace FormWeb.Areas.Placa.Controllers
{
    [Area("Placa")]
    [Authorize]
    public class PlvrstaObrDopKoefController : Controller
    {
        private readonly FormWebCoreContext _context;

        public PlvrstaObrDopKoefController(FormWebCoreContext context)
        {
            _context = context;
        }
        public IActionResult DataSource([FromBody]DataManagerRequest dm)
        {
            var data = (from o in _context.PlvrstaObrDopKoef
                        join d in _context.Pldoprinos on o.DoprinosId equals d.DoprinosId
                        orderby d.IzNa, d.Poz
                        select new
                        {
                            o.RowId,
                            o.VrstaObrDopId,
                            o.DoprinosId,
                            o.Koeficijent
                        }).AsEnumerable();

            DataOperations operation = new DataOperations();

            if (dm.Search != null && dm.Search.Count > 0)
            {
                data = operation.PerformSearching(data, dm.Search);  //Search
            }
            if (dm.Sorted != null && dm.Sorted.Count > 0) //Sorting
            {
                data = operation.PerformSorting(data, dm.Sorted);
            }
            if (dm.Where != null && dm.Where.Count > 0) //Filtering
            {
                data = operation.PerformFiltering(data, dm.Where, dm.Where[0].Operator);
            }
            int count = data.Count();
            if (dm.Skip != 0)
            {
                data = operation.PerformSkip(data, dm.Skip); //Paging
            }
            if (dm.Take != 0)
            {
                data = operation.PerformTake(data, dm.Take);
            }

            return dm.RequiresCounts ? Json(new { result = data, count = count }) : Json(data);
        }

        public IActionResult NormalUpdate([FromBody]CRUDModel<PlvrstaObrDopKoef> value)
        {
            var upd = value.Value;
            _context.Entry(upd).State = EntityState.Modified;
            _context.SaveChanges();
            return Json(value.Value);

        }
        public IActionResult NormalInsert([FromBody]CRUDModel<PlvrstaObrDopKoef> value)
        {
            _context.PlvrstaObrDopKoef.Add(value.Value);
            _context.SaveChanges();
            return Json(value.Value);
        }
        public IActionResult NormalDelete([FromBody]CRUDModel<PlvrstaObrDopKoef> value)
        {
            var ul = _context.PlvrstaObrDopKoef.Find(Convert.ToInt32(value.Key));
            _context.PlvrstaObrDopKoef.Remove(ul);
            _context.SaveChanges();
            return Json(value);
        }
    }
}