﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;
using Microsoft.EntityFrameworkCore;
using FormWeb.Models.DB;
using Syncfusion.EJ2.Base;

namespace FormWeb.Areas.Placa.Pages
{
    public class VrstaObrDopModel : PageModel
    {
        private readonly FormWeb.Models.DB.FormWebCoreContext _context;

        public VrstaObrDopModel(FormWeb.Models.DB.FormWebCoreContext context)
        {
            _context = context;
        }

        public void OnGet()
        {
            var dsDop = from d in _context.Pldoprinos
                        select new
                        {
                            d.DoprinosId,
                            d.Sifra
                        };

            ViewData["dsDop"] = dsDop.ToList();
        }
        public JsonResult OnPostDataSource([FromBody]DataManagerRequest dm)
        {
            var data = (from o in _context.PlvrstaObrDop
                        orderby o.Naziv
                        select o).AsEnumerable();

            DataOperations operation = new DataOperations();

            if (dm.Search != null && dm.Search.Count > 0)
            {
                data = operation.PerformSearching(data, dm.Search);  //Search
            }
            if (dm.Sorted != null && dm.Sorted.Count > 0) //Sorting
            {
                data = operation.PerformSorting(data, dm.Sorted);
            }
            if (dm.Where != null && dm.Where.Count > 0) //Filtering
            {
                data = operation.PerformFiltering(data, dm.Where, dm.Where[0].Operator);
            }
            int count = data.Count();
            if (dm.Skip != 0)
            {
                data = operation.PerformSkip(data, dm.Skip); //Paging
            }
            if (dm.Take != 0)
            {
                data = operation.PerformTake(data, dm.Take);
            }

            return dm.RequiresCounts ? new JsonResult(new { result = data, count = count }) : new JsonResult(data);
        }
        public JsonResult OnPostInsert([FromBody]CRUDModel<PlvrstaObrDop> value)
        {
            _context.PlvrstaObrDop.Add(value.Value);
            _context.SaveChanges();
            return new JsonResult(value.Value);
        }
        public JsonResult OnPostUpdate([FromBody]CRUDModel<PlvrstaObrDop> value)
        {
            var upd = value.Value;
            _context.Entry(upd).State = EntityState.Modified;
            _context.SaveChanges();
            return new JsonResult(value.Value);
        }
        public JsonResult OnPostDelete([FromBody]CRUDModel<PlvrstaObrDop> value)
        {
            var ul = _context.PlvrstaObrDop.Find(Convert.ToInt32(value.Key));
            _context.PlvrstaObrDop.Remove(ul);
            _context.SaveChanges();
            return new JsonResult(value);
        }
    }
}
